# DFP: Dogmatic Functional Procedures

[![Documentation Status](https://readthedocs.org/projects/dogmatic-functional-programming/badge/?version=latest)](https://dogmatic-functional-programming.readthedocs.io/en/latest/?badge=latest)
